<?php

namespace Drupal\migrate_process_markdown_to_html\Plugin\migrate\process;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\migrate\MigrateExecutableInterface;
use Drupal\migrate\ProcessPluginBase;
use Drupal\migrate\Row;
use League\CommonMark\CommonMarkConverter;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a markdown_to_html plugin.
 *
 * Usage:
 *
 * @code
 * process:
 *   bar:
 *     plugin: markdown_to_html
 *     source: foo
 * @endcode
 *
 * @MigrateProcessPlugin(
 *   id = "markdown_to_html"
 * )
 */
class MarkdownToHtml extends ProcessPluginBase implements ContainerFactoryPluginInterface {

  /**
   * Converter for converting markdown to HTML.
   */
  protected CommonMarkConverter $converter;

  /**
   * Constructs a MarkdownToHtml plugin.
   *
   * @param array $configuration
   *   The plugin configuration.
   * @param string $plugin_id
   *   The plugin ID.
   * @param mixed $plugin_definition
   *   The plugin definition.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->converter = new CommonMarkConverter();
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): MarkdownToHtml {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
    );
  }

  /**
   * {@inheritdoc}
   */
  public function transform($value, MigrateExecutableInterface $migrate_executable, Row $row, $destination_property) {
    return $this->converter->convert($value);
  }

}
